@@ -80,7 +80,7 @@ use MIME::Tools qw(:config :msgs);
 #------------------------------
 
 # The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.503";
+$VERSION = "5.507";
 
 
 #------------------------------
@@ -93,7 +93,7 @@ $VERSION = "5.503";
 my $PARAMNAME = '[^\x00-\x1f\x80-\xff :=]+';
 
 # Pattern to match the first value on the line:
-my $FIRST    = '[^\s\;\x00-\x1f\x80-\xff]+';
+my $FIRST    = '[^\s\;\x00-\x1f\x80-\xff]*';
 
 # Pattern to match an RFC 2045 token:
 #
@@ -105,6 +105,8 @@ my $TSPECIAL = '()<>@,;:\</[]?="';
 
 my $TOKEN    = '[^ \x00-\x1f\x80-\xff' . "\Q$TSPECIAL\E" . ']+';
 
+my $QUOTED_STRING = '"([^\\\\"]*(?:\\\\.(?:[^\\\\"]*))*)"';
+
 # Encoded token:
 my $ENCTOKEN = "=\\?[^?]*\\?[A-Za-z]\\?[^?]+\\?=";
 
@@ -207,7 +209,7 @@ sub rfc2231decode {
 }
 
 sub rfc2231percent {
-    # Do percent-subsitution
+    # Do percent-substitution
     my($str) = @_;
     local $1;
     $str =~ s/%([0-9a-fA-F]{2})/pack("C", hex($1))/ge;
@@ -236,17 +238,28 @@ sub parse_params {
     # Extract subsequent parameters.
     # No, we can't just "split" on semicolons: they're legal in quoted strings!
     while (1) {                     # keep chopping away until done...
-	$raw =~ m/\G$SPCZ(\;$SPCZ)+/og or last;             # skip leading separator
+	$raw =~ m/\G[^;]*(\;$SPCZ)+/og or last;             # skip leading separator
 	$raw =~ m/\G($PARAMNAME)\s*=\s*/og or last;      # give up if not a param
 	$param = lc($1);
-	$raw =~ m/\G(?:("([^"]*)")|($ENCTOKEN)|($BADTOKEN)|($TOKEN))/g or last;   # give up if no value"
-	my ($qstr, $str, $enctoken, $badtoken, $token) = ($1, $2, $3, $4, $5);
+	$raw =~ m/\G(?:$QUOTED_STRING|($ENCTOKEN)|($TOKEN)|($BADTOKEN))/g or last;   # give up if no value"
+	my ($qstr, $enctoken, $token, $badtoken) = ($1, $2, $3, $4, $5);
+	if (defined($qstr)) {
+            # unescape
+	    $qstr =~ s/\\(.)/$1/g;
+	}
 	if (defined($badtoken)) {
 	    # Strip leading/trailing whitespace from badtoken
 	    $badtoken =~ s/^\s+//;
 	    $badtoken =~ s/\s+\z//;
+
+	    # Only keep token parameters in badtoken;
+	    # cut it off at the first non-token char.  CPAN RT #105455
+	    $badtoken =~ /^($TOKEN)*/;
+	    $badtoken = $1;
+	    # Cut it off at first whitespace too
+	    $badtoken =~ s/\s.*//;
 	}
-	$val = defined($qstr) ? $str :
+	$val = defined($qstr) ? $qstr :
 	    (defined($enctoken) ? $enctoken :
 	     (defined($badtoken) ? $badtoken : $token));
 
@@ -374,6 +387,7 @@ sub stringify {
     foreach $key (sort keys %$self) {
 	next if ($key !~ /^[a-z][a-z-_0-9]*$/);  # only lowercase ones!
 	defined($val = $self->{$key}) or next;
+        $val =~ s/(["\\])/\\$1/g;
 	$str .= qq{; $key="$val"};
     }
     $str;
